@@ -129,10 +129,11 @@ def api_delete_all_tasks(
 async def read_tasks(
     request: Request,
     db: Session = Depends(get_db),
-    skip: int = 0,
-    limit: int = 1000,
+    # skip: int = 0,
+    # limit: int = 1000,
 ):
-    db_objects = task_crud.read_many(db, skip, limit)
+    # db_objects = task_crud.read_many(db, skip, limit)
+    db_objects = task_crud.read_many(db)
     db_objects = [db_obj.to_dict() for db_obj in db_objects]
     # db_objects = [schemas.Task.from_orm(db_obj) for db_obj in db_objects]
     db_objects = [schemas.Task(**db_obj) for db_obj in db_objects]
@@ -434,7 +435,7 @@ async def read_worker(
 
 @app.get('/logs/', response_class=HTMLResponse)
 async def logs(request: Request):
-    logs = await util.dirstat(static_folder / 'logs')
+    logs = await util.dirstat(os.environ['LOGS_DIRECTORY'])
     for log in logs:
         log['log_id'] = Path(log['name']).stem
     return templates.TemplateResponse('logs.j2', {'request': request, 'logs': logs})
