@@ -12,6 +12,8 @@ SessionLocal = sessionmaker(autocommit=False, autoflush=False, bind=engine)
 
 def create_all():
     models.Base.metadata.create_all(bind=engine)
+    db = SessionLocal()
+    db.close()
 
 
 if __name__ == '__main__':
